"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .state import State
from datetime import datetime
from owasp_nest.types import BaseModel
from typing_extensions import TypedDict


class IssueSchemaTypedDict(TypedDict):
    r"""Schema for Issue."""

    body: str
    created_at: datetime
    title: str
    state: State
    updated_at: datetime
    url: str


class IssueSchema(BaseModel):
    r"""Schema for Issue."""

    body: str

    created_at: datetime

    title: str

    state: State

    updated_at: datetime

    url: str
