"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .memberschema import MemberSchema, MemberSchemaTypedDict
from owasp_nest.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class PagedMemberSchemaTypedDict(TypedDict):
    items: List[MemberSchemaTypedDict]
    count: int


class PagedMemberSchema(BaseModel):
    items: List[MemberSchema]

    count: int
