"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from owasp_nest.types import BaseModel
from typing_extensions import TypedDict


class CommitteeSchemaTypedDict(TypedDict):
    r"""Schema for Committee."""

    name: str
    description: str
    created_at: datetime
    updated_at: datetime


class CommitteeSchema(BaseModel):
    r"""Schema for Committee."""

    name: str

    description: str

    created_at: datetime

    updated_at: datetime
