"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .repositoryschema import RepositorySchema, RepositorySchemaTypedDict
from owasp_nest.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class PagedRepositorySchemaTypedDict(TypedDict):
    items: List[RepositorySchemaTypedDict]
    count: int


class PagedRepositorySchema(BaseModel):
    items: List[RepositorySchema]

    count: int
