"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from owasp_nest.types import BaseModel
from typing_extensions import TypedDict


class ReleaseSchemaTypedDict(TypedDict):
    r"""Schema for Release."""

    created_at: datetime
    description: str
    name: str
    published_at: datetime
    tag_name: str


class ReleaseSchema(BaseModel):
    r"""Schema for Release."""

    created_at: datetime

    description: str

    name: str

    published_at: datetime

    tag_name: str
