"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .releaseschema import ReleaseSchema, ReleaseSchemaTypedDict
from owasp_nest.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class PagedReleaseSchemaTypedDict(TypedDict):
    items: List[ReleaseSchemaTypedDict]
    count: int


class PagedReleaseSchema(BaseModel):
    items: List[ReleaseSchema]

    count: int
