"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .committeeschema import CommitteeSchema, CommitteeSchemaTypedDict
from owasp_nest.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class PagedCommitteeSchemaTypedDict(TypedDict):
    items: List[CommitteeSchemaTypedDict]
    count: int


class PagedCommitteeSchema(BaseModel):
    items: List[CommitteeSchema]

    count: int
