"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from owasp_nest.types import BaseModel
from typing_extensions import TypedDict


class EventSchemaTypedDict(TypedDict):
    r"""Schema for Event."""

    description: str
    name: str
    end_date: datetime
    start_date: datetime
    url: str


class EventSchema(BaseModel):
    r"""Schema for Event."""

    description: str

    name: str

    end_date: datetime

    start_date: datetime

    url: str
