"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .projectschema import ProjectSchema, ProjectSchemaTypedDict
from owasp_nest.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class PagedProjectSchemaTypedDict(TypedDict):
    items: List[ProjectSchemaTypedDict]
    count: int


class PagedProjectSchema(BaseModel):
    items: List[ProjectSchema]

    count: int
