"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from owasp_nest.types import BaseModel
from owasp_nest.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class GetMemberRequestTypedDict(TypedDict):
    login: str


class GetMemberRequest(BaseModel):
    login: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
