"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .projectlevel import ProjectLevel
from datetime import datetime
from owasp_nest.types import BaseModel
from typing_extensions import TypedDict


class ProjectSchemaTypedDict(TypedDict):
    r"""Schema for Project."""

    created_at: datetime
    description: str
    level: ProjectLevel
    r"""Enum for OWASP project levels."""
    name: str
    updated_at: datetime


class ProjectSchema(BaseModel):
    r"""Schema for Project."""

    created_at: datetime

    description: str

    level: ProjectLevel
    r"""Enum for OWASP project levels."""

    name: str

    updated_at: datetime
