"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .chapterschema import ChapterSchema, ChapterSchemaTypedDict
from owasp_nest.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class PagedChapterSchemaTypedDict(TypedDict):
    items: List[ChapterSchemaTypedDict]
    count: int


class PagedChapterSchema(BaseModel):
    items: List[ChapterSchema]

    count: int
