"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .issueschema import IssueSchema, IssueSchemaTypedDict
from owasp_nest.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class PagedIssueSchemaTypedDict(TypedDict):
    items: List[IssueSchemaTypedDict]
    count: int


class PagedIssueSchema(BaseModel):
    items: List[IssueSchema]

    count: int
