"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .organizationschema import OrganizationSchema, OrganizationSchemaTypedDict
from owasp_nest.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class PagedOrganizationSchemaTypedDict(TypedDict):
    items: List[OrganizationSchemaTypedDict]
    count: int


class PagedOrganizationSchema(BaseModel):
    items: List[OrganizationSchema]

    count: int
