"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .eventschema import EventSchema, EventSchemaTypedDict
from owasp_nest.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class PagedEventSchemaTypedDict(TypedDict):
    items: List[EventSchemaTypedDict]
    count: int


class PagedEventSchema(BaseModel):
    items: List[EventSchema]

    count: int
