"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from owasp_nest.types import BaseModel
from typing_extensions import TypedDict


class OrganizationSchemaTypedDict(TypedDict):
    r"""Schema for Organization."""

    company: str
    created_at: datetime
    location: str
    login: str
    name: str
    updated_at: datetime


class OrganizationSchema(BaseModel):
    r"""Schema for Organization."""

    company: str

    created_at: datetime

    location: str

    login: str

    name: str

    updated_at: datetime
