"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from owasp_nest.types import BaseModel
from typing_extensions import TypedDict


class ChapterSchemaTypedDict(TypedDict):
    r"""Schema for Chapter."""

    country: str
    created_at: datetime
    name: str
    region: str
    updated_at: datetime


class ChapterSchema(BaseModel):
    r"""Schema for Chapter."""

    country: str

    created_at: datetime

    name: str

    region: str

    updated_at: datetime
